import React from 'react'
import ago from "s-ago"
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
  TableCaption
} from "@/components/ui/table"
import { Button } from './ui/button'
import {
  Tooltip,
  TooltipContent,
  TooltipProvider,
  TooltipTrigger,
} from "@/components/ui/tooltip"

import BarLoader from "react-spinners/BarLoader"

import sendSignal from "@/lib/pm2"


import { ExternalLink, Octagon, Play, RotateCcw } from "lucide-react";
import Status from './Status'
import { Pm2ProcessList } from '@/types/pm2'


export default function Process({currentServer, processes, loading, loadServer, setSelected} : { currentServer: string, processes: Pm2ProcessList[], loading: boolean, loadServer: Function, setSelected: React.SetStateAction<any> }) {

  return (
    <Table>
      <TableCaption hidden={processes.length !== 0}>{loading ? (<BarLoader />) : "No proccesses."}.</TableCaption>
      <TableHeader>
        <TableRow>
          <TableHead className="w-[100px]">Status</TableHead>
          <TableHead>ID</TableHead>
          <TableHead>Name</TableHead>
          <TableHead>Last Restart</TableHead>
          <TableHead className="text-center">Actions</TableHead>
        </TableRow>
      </TableHeader>
      <TableBody>
        {
          processes.map(proc => (
            <TableRow key={proc.pm2_env.pm_id}>
              <TableCell className="font-medium"><Status status={proc.pm2_env.status} /></TableCell>
              <TableCell>{proc.pm2_env.pm_id}</TableCell>
              <TableCell>{proc.name}</TableCell>
              <TableCell className="font-medium">
                <TooltipProvider>
                  <Tooltip>
                    <TooltipTrigger>{ago(new Date(proc.pm2_env.pm_uptime))}</TooltipTrigger>
                    <TooltipContent>
                      <p>{new Date(proc.pm2_env.pm_uptime).toUTCString()}</p>
                    </TooltipContent>
                  </Tooltip>
                </TooltipProvider>

                
              </TableCell>
              <TableCell className="text-right">
                <div className="flex-row">
                  <Button variant="secondary" className="ml-1" onClick={() => { setSelected(proc.name) }}><ExternalLink /></Button>
                  <Button variant="secondary" className="ml-1" onClick={() => {sendSignal(currentServer, proc.name, "resume", loadServer)}}><Play /></Button>
                  <Button variant="secondary" className="ml-1" onClick={() => {sendSignal(currentServer, proc.name, "stop", loadServer)}}><Octagon /></Button>
                  <Button variant="secondary" className="ml-1" onClick={() => {sendSignal(currentServer, proc.name, "restart", loadServer)}}><RotateCcw /></Button>
                </div>
              </TableCell>
            </TableRow>
          ))
        }
      </TableBody>
    </Table>
  )
}
