"use client"

import * as React from "react"
import { Check, ChevronsUpDown, TrashIcon } from "lucide-react"

import { cn } from "@/lib/utils"
import { Button } from "@/components/ui/button"
import {
  Command,
  CommandEmpty,
  CommandGroup,
  CommandInput,
  CommandItem,
  CommandList,
} from "@/components/ui/command"
import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover"
import { Label } from "./ui/label"
import { Input } from "./ui/input"
import { useToast } from "@/hooks/use-toast"
import { Option } from "@/types/types"

export function ServerSelector({savedServers, setSavedServers, currentServ, setCurrentServ} : { savedServers: Option[], setSavedServers: React.SetStateAction<any>, currentServ: string, setCurrentServ: React.SetStateAction<any>}) {
  const { toast } = useToast();
  const [open, setOpen] = React.useState(false)

  const [newName, setNewName] = React.useState("");
  const [newAddr, setNewAddr] = React.useState("");
  const [newToken, setNewToken] = React.useState("");

  const handleDelete = (e : any) => {
    const servToDel = e.target.parentElement.id;
    if (!confirm(`Are you sure you want to delete ${servToDel}?`)) return;
    console.log(servToDel)
    const editedList = savedServers.filter(s => s.value !== servToDel);
    updateSavedServers(editedList);
    setSavedServers(editedList);
    let storedToks = localStorage.getItem("tokens");
    if (storedToks) {
      const currToks = JSON.parse(storedToks)
      const editedToks = currToks.filter((t: {server:string, token: string}) => t.server !== servToDel); 
      localStorage.setItem("tokens", JSON.stringify(editedToks));
    }
    setCurrentServ(null);
  }

  const updateSavedServers = (newList : Array<{label:string, value:string}>) => {
    localStorage.setItem("savedServers", JSON.stringify(newList));
  }

  const loadSavedServers = () => {
    const localSaved = localStorage.getItem("savedServers");
    if (!localSaved) return;

    setSavedServers(JSON.parse(localSaved));
  }

  const handleServerAdd = () => {
    if (newName === "" || newAddr === "") {
        toast({
            title: "Not enough info!",
            description: "Enter a Name & Address for new Server.",
            variant: "destructive"
            // action: <ToastAction altText="Try again">Try again</ToastAction>,
        })
        return;
    };

    const names = savedServers.map((s: Option) => s.label);
    const addrs = savedServers.map((s : Option) => s.value);

    if (names.includes(newName) || addrs.includes(newAddr)) {
        toast({
            title: "Server already exists!",
            description: "A server with this name already exists.",
            variant: "destructive"
        })
        return;
    }

    let storedToks = localStorage.getItem("tokens");
    let currToks;
    if (!storedToks) {
      currToks = [];
    } else {
      currToks = JSON.parse(storedToks)
    }
    const newToks = JSON.stringify([...currToks, { server: newAddr, token: newToken }])
    localStorage.setItem("tokens", newToks);

    const newList = [...savedServers, {label: newName, value: newAddr}]
    setSavedServers(newList);
    updateSavedServers(newList);
    toast({
        title: "Added Server!",
        description: "You can select it now.",
    })
    }

  React.useEffect(() => {
    loadSavedServers()
  }, [])

  return (
    <Popover open={open} onOpenChange={setOpen}>
      <PopoverTrigger asChild>
        <Button
          variant="outline"
          role="combobox"
          aria-expanded={open}
          className="w-[200px] justify-between"
        >
          {currentServ
            ? savedServers.find((serv) => serv.value === currentServ)?.label
            : "Select server..."}
          <ChevronsUpDown className="ml-2 h-4 w-4 shrink-0 opacity-50" />
        </Button>
      </PopoverTrigger>
      <PopoverContent className="w-[200px] p-0">
        <Command>
          <CommandInput placeholder="Search server..."/>
          <CommandList>
            <CommandEmpty>
            <Popover>
                <PopoverTrigger><Button variant="secondary">Connect New Server</Button></PopoverTrigger>
                <PopoverContent className="w-80">
                    <div className="grid gap-4">
                    <div className="space-y-2">
                        <h4 className="font-medium leading-none">New Server</h4>
                        <p className="text-sm text-muted-foreground">
                        Enter Information for New Server.
                        </p>
                    </div>
                    <div className="grid gap-2">
                        <div className="grid grid-cols-3 items-center gap-4">
                        <Label htmlFor="name">Server Name</Label>
                        <Input
                            id="name"
                            placeholder="New Server"
                            className="col-span-2 h-8"
                            onChange={(e) => setNewName(e.target.value)}
                        />
                        </div>
                        <div className="grid grid-cols-3 items-center gap-4">
                        <Label htmlFor="address">Server Address</Label>
                        <Input
                            id="token"
                            placeholder="http://192.168.0.12:2222"
                            className="col-span-2 h-8"
                            onChange={(e) => setNewAddr(e.target.value)}
                        />
                        <Label htmlFor="token">Access Token</Label>
                        <Input
                            id="token"
                            placeholder="optional"
                            className="col-span-2 h-8"
                            onChange={(e) => setNewToken(e.target.value)}
                        />
                        </div>
                    </div>
                    <div className="grid gap-2">
                        <Button onClick={handleServerAdd}>Add</Button>
                    </div>
                    </div>
                </PopoverContent>
            </Popover>

                {/*  */}
            </CommandEmpty>
            <CommandGroup>
              {savedServers.map((server : Option) => (
                <CommandItem
                  key={server.value}
                  value={server.value}
                  onSelect={(currentValue) => {
                    setCurrentServ(currentValue === currentServ ? "" : currentValue)
                    setOpen(false)
                  }}
                >
                  <Check
                    className={cn(
                      "mr-2 h-4 w-4",
                      currentServ === server.value ? "opacity-100" : "opacity-0"
                    )}
                  />
                  {server.label}
                  <div className="ml-auto cursor-pointer bg-gray-200 p-1 rounded" id={server.value} onClick={handleDelete}>
                    <TrashIcon />
                  </div>
                </CommandItem>
              ))}
            </CommandGroup>
          </CommandList>
        </Command>
      </PopoverContent>
    </Popover>
  )
}
