export interface Pm2ProcessList {
    pid: number;
    name: string;
    pm2_env: Pm2Env;
    pm_id: number;
    monit: Monit;
}

export interface Pm2Env {
    prev_restart_delay: number;
    kill_retry_time: number;
    windowsHide: boolean;
    username: string;
    treekill: boolean;
    automation: boolean;
    pmx: boolean;
    instance_var: string;
    watch: boolean;
    autorestart: boolean;
    autostart: boolean;
    vizion: boolean;
    merge_logs: boolean;
    env: Environment;
    namespace: string;
    filter_env: string[];
    node_args: string[];
    pm_exec_path: string;
    pm_cwd: string;
    exec_interpreter: string;
    exec_mode: string;
    instances: number;
    pm_out_log_path: string;
    pm_err_log_path: string;
    pm_pid_path: string;
    km_link: boolean;
    vizion_running: boolean;
    NODE_APP_INSTANCE: number;
    HOSTTYPE: string;
    LANG: string;
    PATH: string;
    TERM: string;
    XDG_RUNTIME_DIR: string;
    DISPLAY: string;
    WAYLAND_DISPLAY: string;
    PULSE_SERVER: string;
    WSL2_GUI_APPS_ENABLED: string;
    WSLENV: string;
    WT_SESSION: string;
    WT_PROFILE_ID: string;
    WSL_INTEROP: string;
    NAME: string;
    HOME: string;
    USER: string;
    LOGNAME: string;
    SHELL: string;
    WSL_DISTRO_NAME: string;
    DBUS_SESSION_BUS_ADDRESS: string;
    SHLVL: string;
    PWD: string;
    OLDPWD: string;
    ZSH: string;
    PAGER: string;
    LESS: string;
    LSCOLORS: string;
    LS_COLORS: string;
    NVM_DIR: string;
    NVM_CD_FLAGS: string;
    NVM_BIN: string;
    NVM_INC: string;
    _: string;
    PM2_USAGE: string;
    PM2_HOME: string;
    unique_id: string;
    status: string;
    pm_uptime: number;
    axm_actions: AxmAction[];
    axm_monitor: AxmMonitor;
    axm_options: AxmOptions;
    axm_dynamic: Record<string, unknown>;
    created_at: number;
    pm_id: number;
    restart_time: number;
    unstable_restarts: number;
    version: string;
    versioning: null | Versioning;
    node_version: string;
    exit_code: number;
}

export interface Environment {
    [key: string]: string | number | boolean | undefined;
}

export interface AxmAction {
    action_name: string;
    action_type: string;
    arity: number;
}

export interface AxmMonitor {
    "Used Heap Size": AxmMetric;
    "Heap Usage": AxmMetric;
    "Heap Size": AxmMetric;
    "Event Loop Latency p95": AxmMetric;
    "Event Loop Latency": AxmMetric;
    "Active handles": AxmMetric;
    "Active requests": AxmMetric;
    HTTP: AxmMetric;
    "HTTP P95 Latency": AxmMetric;
    "HTTP Mean Latency": AxmMetric;
}

export interface AxmMetric {
    value: string | number;
    type: string;
    unit?: string;
    historic: boolean;
}

export interface AxmOptions {
    error: boolean;
    heapdump: boolean;
    "feature.profiler.heapsnapshot": boolean;
    "feature.profiler.heapsampling": boolean;
    "feature.profiler.cpu_js": boolean;
    latency: boolean;
    catchExceptions: boolean;
    profiling: boolean;
    metrics: AxmMetrics;
    standalone: boolean;
    module_conf: Record<string, unknown>;
    apm: Apm;
    module_name: string;
    module_version: string;
}

export interface AxmMetrics {
    http: boolean;
    runtime: boolean;
    eventLoop: boolean;
    network: boolean;
    v8: boolean;
}

export interface Apm {
    version: string;
    type: string;
}

export interface Versioning {
    [key: string]: any; // Adjust this according to actual data if available.
}

export interface Monit {
    memory: number;
    cpu: number;
}